[Unit]
Description={{ service_name }} service

[Service]
Type=notify
ExecStart={{ service_path }}/{{ service_name }} --config-file {{ config_file }}
User=ironic
RuntimeDirectory=ironic
RuntimeDirectoryMode=750
RuntimeDirectoryPreserve=yes

[Install]
WantedBy=multi-user.target
Alias={{ service_name }}.service
